@@ -1,11 +1,12 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2b.h"
 
+#include "c2bClipboard.h"
 #include "c2bConfigure.h"
 #include "ui_proxyDialog.h"
 
@@ -20,33 +21,37 @@
 */
 c2b::c2b(QWidget* main, QObject* parento) : QObject(parento)
 {
-    Q_ASSERT_X(!c2b_single_instance, "c2b", "cb2Bib resources already instantiated");
-    c2b::c2b_single_instance = this;
-    c2b_main = main;
+    Q_ASSERT_X(!_c2b_single_instance, "c2b", "cb2Bib resources already instantiated");
+    c2b::_c2b_single_instance = this;
+    _c2b_main = main;
 
-    if (c2b_main->inherits("cb2Bib"))
+    if (_c2b_main->inherits("cb2Bib"))
     {
-        // Creating Bibliographic Parser
-        c2b_bibparser = new c2bBibParser(this);
+        // Create bibliographic parser
+        _c2b_bibparser = new c2bBibParser(this);
 
-        // Creating cb2Bib network
-        c2b_network = new network(this);
-        connect(c2b_network, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
+        // Create cb2Bib network
+        _c2b_network = new network(this);
+        connect(_c2b_network, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
                 this, SLOT(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
-        connect(c2b_network, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgress(qint64, qint64)));
-        downloadProgress = new QProgressDialog(c2b_main);
-        downloadProgress->setWindowTitle("cb2Bib");
-        connect(downloadProgress, SIGNAL(canceled()), c2b_network, SLOT(cancelDownload()));
+        connect(_c2b_network, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgress(qint64, qint64)));
+        _download_progress = new QProgressDialog(_c2b_main);
+        _download_progress->setWindowTitle("cb2Bib");
+        connect(_download_progress, SIGNAL(canceled()), _c2b_network, SLOT(cancelDownload()));
 
-        // Creating cb2Bib network query info
-        c2b_netqinf = new c2bNetworkQueryInfo(this);
+        // Create cb2Bib network query info
+        _c2b_netqinf = new c2bNetworkQueryInfo(this);
 
-        // Creating cb2Bib metadata parser
-        c2b_metadataparser = new metadataParser(c2b_bibparser, this);
-        connect(c2b_metadataparser, SIGNAL(showMessage(const QString&, const QString&)),
+        // Create cb2Bib metadata parser
+        _c2b_metadataparser = new metadataParser(_c2b_bibparser, this);
+        connect(_c2b_metadataparser, SIGNAL(showMessage(const QString&, const QString&)),
                 this, SLOT(showMessage(const QString&, const QString&)));
+
+        // Create cb2Bib clipboard
+        _c2b_clipboard = new c2bClipboard(this);
+        _c2b_clipboard->setConnected(true);
     }
-    else if (c2b_main->inherits("c2bAnnote"))
+    else if (_c2b_main->inherits("c2bAnnote"))
     {
         // Nothing is needed at present for the c2bAnnote
     }
@@ -56,16 +61,16 @@ c2b::c2b(QWidget* main, QObject* parento) : QObject(parento)
 
 c2b::~c2b()
 {
-    c2b_single_instance = 0;
+    _c2b_single_instance = 0;
 }
 
 
-c2b* c2b::c2b_single_instance = 0;
+c2b* c2b::_c2b_single_instance = 0;
 
 
 void c2b::showMessage(const QString& title, const QString& ms)
 {
-    QMessageBox::warning(c2b_main, title, ms, QMessageBox::Ok);
+    QMessageBox::warning(_c2b_main, title, ms, QMessageBox::Ok);
 }
 
 void c2b::configure(int index)
@@ -82,7 +87,7 @@ void c2b::configure(int index)
 
 void c2b::exitRequested()
 {
-    foreach(QWidget* w, QApplication::topLevelWidgets())
+    foreach(QWidget * w, QApplication::topLevelWidgets())
     {
         // So far only editors grant user exit cancellation
         // Avoid closing other visible widgets until exit is granted
@@ -91,7 +96,7 @@ void c2b::exitRequested()
                 w->close();
     }
     qApp->processEvents();
-    foreach(QWidget* widget, QApplication::topLevelWidgets())
+    foreach(QWidget * widget, QApplication::topLevelWidgets())
     {
         if (widget->isVisible())
             if (widget->inherits("c2bEditor"))
@@ -109,17 +114,17 @@ void c2b::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
         return;
     if (bytesReceived == bytesTotal)
     {
-        downloadProgress->reset();
+        _download_progress->reset();
         return;
     }
-    downloadProgress->setLabelText(tr("Retrieving from %1...").arg(QUrl(c2b_network->sourceFilename()).host()));
-    downloadProgress->setMaximum((int)bytesTotal);
-    downloadProgress->setValue((int)bytesReceived);
+    _download_progress->setLabelText(tr("Retrieving from %1...").arg(QUrl(_c2b_network->sourceFilename()).host()));
+    _download_progress->setMaximum((int)bytesTotal);
+    _download_progress->setValue((int)bytesReceived);
 }
 
 void c2b::proxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator* auth)
 {
-    QDialog dialog(c2b_main);
+    QDialog dialog(_c2b_main);
     Ui::proxyDialog proxyDialog;
     proxyDialog.setupUi(&dialog);
     dialog.setWindowTitle(tr("Proxy %1 Authentication - cb2Bib").arg(proxy.hostName()));
@@ -129,5 +134,5 @@ void c2b::proxyAuthenticationRequired(const QNetworkProxy& proxy, QAuthenticator
         auth->setPassword(proxyDialog.passwordLineEdit->text());
     }
     else
-        c2b_network->cancelDownload();
+        _c2b_network->cancelDownload();
 }
