@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2B_H
@@ -15,6 +15,9 @@
 
 #include <QObject>
 
+
+class c2bClipboard;
+
 class QProgressDialog;
 class QWidget;
 
@@ -52,33 +55,38 @@ public:
     // Pointers
     inline static c2b* instance()
     {
-        Q_ASSERT_X(c2b_single_instance, "c2b", "cb2Bib resources were not instantiated");
-        return c2b_single_instance;
+        Q_ASSERT_X(_c2b_single_instance, "c2b", "cb2Bib resources were not instantiated");
+        return _c2b_single_instance;
     }
 
     inline static QWidget* mainWidget()
     {
-        return instance()->c2b_main;
+        return instance()->_c2b_main;
+    }
+
+    inline static c2bClipboard* clipboard()
+    {
+        return instance()->_c2b_clipboard;
     }
 
     inline static network* net()
     {
-        return instance()->c2b_network;
+        return instance()->_c2b_network;
     }
 
     inline static c2bNetworkQueryInfo* netqinf()
     {
-        return instance()->c2b_netqinf;
+        return instance()->_c2b_netqinf;
     }
 
     inline static c2bBibParser* bibParser()
     {
-        return instance()->c2b_bibparser;
+        return instance()->_c2b_bibparser;
     }
 
     inline static metadataParser* metaParser()
     {
-        return instance()->c2b_metadataparser;
+        return instance()->_c2b_metadataparser;
     }
 
 
@@ -93,13 +101,14 @@ signals:
 
 
 private:
-    QProgressDialog* downloadProgress;
-    QWidget* c2b_main;
-    c2bBibParser* c2b_bibparser;
-    c2bNetworkQueryInfo* c2b_netqinf;
-    metadataParser* c2b_metadataparser;
-    network* c2b_network;
-    static c2b* c2b_single_instance;
+    QProgressDialog* _download_progress;
+    QWidget* _c2b_main;
+    c2bBibParser* _c2b_bibparser;
+    c2bClipboard* _c2b_clipboard;
+    c2bNetworkQueryInfo* _c2b_netqinf;
+    metadataParser* _c2b_metadataparser;
+    network* _c2b_network;
+    static c2b* _c2b_single_instance;
 
     inline void emitMessage(const QString& message)
     {
