@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibExtractor.h"
@@ -27,7 +27,7 @@ bibExtractor::bibExtractor(QObject* parento) : QObject(parento), cout(*(new QTex
 }
 
 bibExtractor::bibExtractor(bibParser* bp, metadataParser* mp, networkQuery* nq, QObject* parento) :
-        QObject(parento), cout(*(new QTextStream(stdout))), _bpP(bp), _mpP(mp), _networkQP(nq)
+    QObject(parento), cout(*(new QTextStream(stdout))), _bpP(bp), _mpP(mp), _networkQP(nq)
 {
     _settingsP = settings::instance();
     Q_ASSERT_X(_bpP, "bibExtractor", "bibParser was not instantiated");
@@ -179,16 +179,18 @@ void bibExtractor::extract(const QString& text)
 void bibExtractor::_extract(const QString& text)
 {
     _bpP->clearCurrentReference();
+    _bpP->setReferenceType("unknown");
     if (text.trimmed().isEmpty())
     {
         logMessage(tr("Warning: Empty input string."));
         return;
     }
-    _bpP->setReferenceType("article");
     QString out_text, out_tagtext;
     if (_settingsP->value("cb2Bib/PreparserAutomatic").toBool())
         _bpP->preparse(text, &out_text);
     _bpP->parse(text, &out_text, &out_tagtext);
+    if (_bpP->fieldCount() > 0)
+        _bpP->setReferenceType("article");
     logMessage(_bpP->autoRecognizedString());
 }
 
@@ -225,7 +227,7 @@ void bibExtractor::logMessage(const QString& ms) const
 bool bibExtractor::isReliable() const
 {
     if (_settingsP->cl_sloppy)
-        return _bpP->fieldCount() > 0;
+        return true;
     else
         return _bpP->isAutoRecognized();
 }
