@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
@@ -88,6 +88,8 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         else
             v = init_value + " and " + _authorString.toBibTeX(v, _settingsP->value("cb2Bib/UseFullNames").toBool());
     }
+    else if (field == "doi")
+        v.remove(QRegExp("^.+(?=10\\.[\\d\\.]+/\\S+)"));
     else if (field == "journal")
     {
         if (_settingsP->value("cb2Bib/SetJournalsToFullname").toBool())
@@ -100,6 +102,9 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         v.replace(" - ", ",");
         QStringList kl(v.split(QRegExp("[^\\w\\s-']"), QString::SkipEmptyParts));
         kl.removeAll(" ");
+#if QT_VERSION >= 0x040500
+        kl.removeDuplicates();
+#endif
         v = kl.join(", ");
         v.replace(QRegExp("\\s+,"), ",");
         v = v.toLower();
@@ -285,7 +290,7 @@ void bibParser::preparse(const QString& text, QString* out_text)
 
     - Check if input stream is already a BibTeX entry. If so, process entry.
 
-    - Check if input stream is a PubMed - Medline Journal entry. If so, process entry.
+    - Check if input stream is a PubMed XML or Medline entry. If so, process entry.
 
     - Preprocess author names: PI JOAN III -> Pi III, J.
     (care of name prefixes, suffixes, and removal of ambiguities).
@@ -310,7 +315,7 @@ void bibParser::preparse(const QString& text, QString* out_text)
 
 
     If the automatic recognition engine fails, optionally, a heuristic guessing
-    will be performed. See also \ref heuristic_guess and \ref metadata.
+    will be performed. See also \ref heuristicguess and \ref metadata.
 
 */
 void bibParser::parse(const QString& text, QString* out_text, QString* out_tagtext)
@@ -349,13 +354,14 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
         _current_reference.typeName = "article";
         otext = ' ' + otext;
         ottext = otext;
-        ottext.replace(QRegExp("[\\n\\r]\\s*([A-Z]{1,4}\\s*-)"), "][\\1");
+        // http://www.nlm.nih.gov/bsd/mms/medlineelements.html
+        ottext.replace(QRegExp("[\\n\\r]\\s*([A-Z]{2,4}\\s*-)"), "][\\1"); // Two to four capital letter in field tags
         ottext = c2bUtils::simplifyString(ottext);
         if (!ottext.contains(QRegExp("\\[FAU\\s+-")))
             ottext.replace(QRegExp("\\[(AU\\s*-\\s*[-'\\w]+)"), "[F\\1 ");
         QStringList fList(ottext.split("]["));
         QString kw;
-        QRegExp fld("^([A-Z]{1,4})\\s{0,1}-\\s*(.+)$");
+        QRegExp fld("^([A-Z]{2,4})\\s{0,1}-\\s*(.+)$");
         fld.setPatternSyntax(QRegExp::RegExp2);
         for (QStringList::Iterator it = fList.begin(); it != fList.end(); ++it)
         {
@@ -399,28 +405,7 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
         return;
     }
 
-    QRegExp rxdoi("(10.[\\d\\.]+/\\S+)");
-    if (rxdoi.indexIn(otext) > -1)
-    {
-        QString cdoi(rxdoi.cap(1));
-        // This happens when publishers set doi to title in metadata: <title>doi:10. ... </title>
-        if (cdoi.endsWith("</title>"))
-            cdoi.chop(8);
-        if (cdoi.endsWith(','))
-            cdoi.chop(1);
-        _current_reference["doi"] = parse("doi", cdoi);
-    }
-
-    QRegExp rxarxiv("arXiv:([\\w\\./-]+)");
-    if (rxarxiv.indexIn(otext) > -1)
-    {
-        _current_reference["journal"] = parse("journal", rxarxiv.cap(0));
-        _current_reference["url"] = parse("url", QString("http://arxiv.org/abs/%1").arg(rxarxiv.cap(1)));
-    }
-
-    QRegExp rxhtml("((http://|https://|ftp://|www\\.|ftp\\.)(www\\.|ftp\\.){0,1}\\S+)");
-    if (rxhtml.indexIn(otext) > -1)
-        _current_reference["url"] = parse("url", rxhtml.cap(1));
+    _heuristic_parserP->heuristicFields(otext);
 
     // Set tags and start regular expression extraction
     ottext = setTags(otext);
@@ -538,6 +523,7 @@ void bibParser::guessFields(const QString& text)
 {
     const QString clean_text(text.simplified());
     const QString tagged_text(setTags(text));
+    _heuristic_parserP->heuristicFields(clean_text);
     _heuristic_parserP->guessFields(clean_text, tagged_text);
     currentReferenceUpdated();
     _auto_recognized_string = tr("%1 fields guessed.").arg(fieldCount());
@@ -558,7 +544,7 @@ QString bibParser::setTags(const QString& text) const
     tagged_text += spText[n-1];
     spText = tagged_text.split(QRegExp("(\\s{10,}|\\t)"));
     n = spText.count();
-    tagged_text = "";
+    tagged_text.clear();
     for (int i = 0; i < n - 1; i++)
         tagged_text += spText.at(i) + QString("<Tab%1>").arg(i + 1);
     tagged_text += spText[n-1];
