@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef BIBREFERENCE_H
@@ -60,7 +60,12 @@ public:
     {
         const QString v(value("title"));
         if (v.isEmpty())
-            return value("booktitle");
+        {
+            const QString v1(value("booktitle"));
+            if (v1.isEmpty())
+                return QFileInfo(value("file")).fileName();
+            return v1;
+        }
         return v;
     }
     /**
