@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -15,20 +15,20 @@
 
 
 heuristicBibParser::heuristicBibParser(bibParser* bp) :
-        _bpP(bp),
-        _current_reference(bp->_current_reference),
-        _abstract("abstract"),
-        _addauthors("addauthors"),
-        _author("author"),
-        _isbn("isbn"),
-        _keywords("keywords"),
-        _number("number"),
-        _pages("pages"),
-        _title("title"),
-        _volume("volume"),
-        _year("year"),
-        _bibliographic_fields(bp->_bibliographic_fields),
-        _journal_db(*bp->_journal_dbP)
+    _bpP(bp),
+    _current_reference(bp->_current_reference),
+    _abstract("abstract"),
+    _addauthors("addauthors"),
+    _author("author"),
+    _isbn("isbn"),
+    _keywords("keywords"),
+    _number("number"),
+    _pages("pages"),
+    _title("title"),
+    _volume("volume"),
+    _year("year"),
+    _bibliographic_fields(bp->_bibliographic_fields),
+    _journal_db(*bp->_journal_dbP)
 {
     _leading_non_letters = QRegExp("^[^<\\w]+");
     // Char 65533 appears many times in pdftotext outputs on windows (seems an encoding error, though)
@@ -136,7 +136,34 @@ void heuristicBibParser::guessFields(const QString& clean_text, const QString& t
     guessFromMetadata(clean_text);
 }
 
-/** \page heuristic_guess Field Recognition Rules
+void heuristicBibParser::heuristicFields(const QString& text)
+{
+    // Heuristics for reasonably secure extraction
+    QRegExp rxdoi("(10\\.[\\d\\.]+/\\S+)");
+    if (rxdoi.indexIn(text) > -1)
+    {
+        QString cdoi(rxdoi.cap(1));
+        // This happens when publishers set doi to title in metadata: <title>doi:10. ... </title>
+        if (cdoi.endsWith("</title>"))
+            cdoi.chop(8);
+        if (cdoi.endsWith(','))
+            cdoi.chop(1);
+        _current_reference["doi"] = _bpP->parse("doi", cdoi);
+    }
+
+    QRegExp rxarxiv("arXiv:([\\w\\./-]+)");
+    if (rxarxiv.indexIn(text) > -1)
+    {
+        _current_reference["journal"] = _bpP->parse("journal", rxarxiv.cap(0));
+        _current_reference["url"] = _bpP->parse("url", QString("http://arxiv.org/abs/%1").arg(rxarxiv.cap(1)));
+    }
+
+    QRegExp rxhtml("((http://|https://|ftp://|www\\.|ftp\\.)(www\\.|ftp\\.){0,1}\\S+)");
+    if (rxhtml.indexIn(text) > -1)
+        _current_reference["url"] = _bpP->parse("url", rxhtml.cap(1));
+}
+
+/** \page heuristicguess Field Recognition Rules
 
 - <b>Abstract</b>
   - If <tt>Abstract\b</tt> is found.
@@ -235,7 +262,7 @@ void heuristicBibParser::guessAbstract(const QString& text)
     }
 }
 
-/** \page heuristic_guess Field Recognition Rules
+/** \page heuristicguess Field Recognition Rules
 
 - <b>Author</b>
   - Check capitalization patterns. See
@@ -343,7 +370,7 @@ int heuristicBibParser::authorCount(const QString& authors) const
     return 1 + authors.count(" and ");
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Keywords</b>
   - If <tt>Key\\s{0,1}words\b</tt> is found.
@@ -370,7 +397,7 @@ void heuristicBibParser::guessKeywords(const QString& text)
     }
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Volume</b>
   - If <tt>Volume:{0,1}</tt> is found.
@@ -419,14 +446,14 @@ void heuristicBibParser::guessVolume(const QString& text)
         _current_reference[_volume] = _bpP->parse(_volume, rxH.cap(1));
         return;
     }
-    rxH = QRegExp("\\b(\\d+)[,:]\\s*" + _hyphen_nums, Qt::CaseInsensitive);
+    rxH = QRegExp("\\b(\\d+)\\s*\\(\\d+\\)");
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
         _current_reference[_volume] = _bpP->parse(_volume, rxH.cap(1));
         return;
     }
-    rxH = QRegExp("\\b(\\d+)\\s*\\(\\d+\\)");
+    rxH = QRegExp("\\b(\\d+)[,:]\\s*" + _hyphen_nums, Qt::CaseInsensitive);
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
@@ -439,7 +466,7 @@ void heuristicBibParser::guessVolume(const QString& text)
         _current_reference[_volume] = _bpP->parse(_volume, rxH.cap(1));
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Number</b>
   - If <tt>Numbers{0,1}:{0,1}\\s*([\\d-]+)</tt> is found.
@@ -480,7 +507,7 @@ void heuristicBibParser::guessNumber(const QString& text)
             _current_reference[_number] = _bpP->parse(_number, rxH.cap(1));
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Pages</b>
   - If <tt>\\bPages{0,1}[:\\.]{0,1}([\\d\\s-]+)</tt> is found.
@@ -554,7 +581,7 @@ void heuristicBibParser::guessPages(const QString& text)
     }
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Year</b>
   - If <tt>\\b(19|20)(\\d\\d)\\b</tt> is found.
@@ -597,7 +624,7 @@ void heuristicBibParser::guessYear(const QString& text)
     }
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Title</b>
   - If <tt>\\bTitle:{0,1}</tt> is found.
@@ -624,7 +651,7 @@ void heuristicBibParser::guessTitle(const QString& text)
     }
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>ISBN</b>
   - If <tt>\\bISBN\\b(?:-\\d+){0,1}:{0,1}(?:-\\d+){0,1}\\s*(\\d+-[\\d-]+-\\d+)</tt> is found.
@@ -649,7 +676,7 @@ void heuristicBibParser::guessISBN(const QString& text)
     }
 }
 
-/** \page heuristic_guess
+/** \page heuristicguess
 
 - <b>Journal</b>
   - Check cb2Bib internal database.
@@ -780,7 +807,7 @@ void heuristicBibParser::guessYearVolumePages(const QString& text)
         return;
     // J. Sci. 1995 January 25; 247(4):536-40.
     // J. Sci. 1995, 247(4):536-40.
-    QRegExp rxH(_current_reference.value(_year) + "[\\w ]{0,15}[,:; ]\\s*(\\d+)\\((" + _hyphen_nums + ")\\)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
+    QRegExp rxH(_current_reference.value(_year) + "[\\w ]{0,15}[,:; ]\\s*(\\d+)\\s*\\((" + _hyphen_nums + ")\\)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
     int nH(rxH.indexIn(text));
     if (nH > -1)
     {
