@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "network.h"
@@ -72,7 +72,7 @@ void network::cancelDownload()
 
 bool network::getFilePrivate(const QString& orig, const QString& dest, const QString& action)
 {
-    _getfile_error_string = "";
+    _getfile_error_string.clear();
     _source_filename = orig;
     _destination_filename = dest;
     if (!checkDestination())
