@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "networkQuery.h"
@@ -50,7 +50,7 @@ void networkQuery::submitQuery(const bibReference& reference, const QString& raw
     _Qvolume = reference.value("volume");
     _Qpage = c2bUtils::firstPage(reference.value("pages"));
     _Qdoi = reference.value("doi").trimmed();
-    if (!_Qdoi.isEmpty() && !_Qdoi.contains(QRegExp("^10.[\\d\\.]+/\\S+$")))
+    if (!_Qdoi.isEmpty() && !_Qdoi.contains(QRegExp("^10\\.[\\d\\.]+/\\S+$")))
     {
         _Qdoi.clear();
         c2bUtils::warn(tr("Warning: DOI skipped: '%1' is not a valid DOI").arg(_Qdoi));
@@ -117,7 +117,8 @@ void networkQuery::submitQuery2(bool stat)
     if (!stat)
     {
         _error_string = _networkP->errorString();
-        emit queryEnded(false, _targetQ, _networkquery_tmp_fn1);
+        emit statusMessage(tr("Query failed with %1.").arg(_error_string));
+        QTimer::singleShot(10, this, SLOT(submitQuery1()));
         return;
     }
 
