@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibParser.h"
@@ -71,9 +71,14 @@ void c2bBibParser::currentReferenceUpdated()
 void c2bBibParser::clearCurrentReference()
 {
     _bp_updates_gui = true;
+    // Clear by setting empty QString as a workaround for bug
+    // http://bugreports.qt.nokia.com/browse/QTBUG-7866
+    // Affects versions 4.6.x, expected to be fixed in 4.6.3
     for (int i = 0; i < _bibliographic_fields.count(); ++i)
-        _field_editors[_bibliographic_fields.at(i)]->clear();
-    _field_editors["id"]->clear();
+        _field_editors[_bibliographic_fields.at(i)]->setText(QString());
+//        _field_editors[_bibliographic_fields.at(i)]->clear();
+    _field_editors["id"]->setText(QString());
+//    _field_editors["id"]->clear();
     bibParser::clearCurrentReference();
     _current_reference.typeName = "article";
     _type_editor->setCurrentIndex(1);
@@ -154,10 +159,10 @@ void c2bBibParser::setWidgetMapping()
     {
         const QString& name = _bibliographic_fields.at(i);
         connect(_field_editors.value(name), SIGNAL(returnPressed()), this, SLOT(setField()));
-        connect(_field_editors.value(name), SIGNAL(textChanged(const QString &)), this, SLOT(referenceEdited(const QString&)));
+        connect(_field_editors.value(name), SIGNAL(textChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
     }
-    connect(_field_editors.value("id"), SIGNAL(textChanged(const QString &)), this, SLOT(referenceEdited(const QString&)));
-    connect(_type_editor, SIGNAL(editTextChanged(const QString &)), this, SLOT(referenceEdited(const QString&)));
+    connect(_field_editors.value("id"), SIGNAL(textChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
+    connect(_type_editor, SIGNAL(editTextChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
 }
 
 void c2bBibParser::showLog(const QString& log)
