@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITER_H
@@ -46,11 +46,11 @@ protected:
 
 
 private:
-    QLabel* citationFilterIcon;
     QString _filter_string;
     QStringList _bibtex_files;
     QSystemTrayIcon* _tray_icon;
     Ui::c2bCiter ui;
+    bool _clipboard_connected;
     bool _filter_mode;
     bool _view_selected;
     c2bCiterModel* _citations;
@@ -61,6 +61,7 @@ private:
     void editReference();
     void openFile();
     void openUrl();
+    void reload(const c2bCiterModel::State& state);
     void setActions();
     void setFilter(const bool do_filter);
     void toggleSelectedFilter();
@@ -69,12 +70,14 @@ private:
 
 private slots:
     void doSearchInFiles();
+    void filterDataChanged(const QString& filter);
     void help();
     void openDirectory();
     void openFiles();
     void reload();
     void showMessage(const QString& ms);
     void toggleCb2Bib();
+    void toggleClipboard();
     void toggleFullScreen();
     void trayIconActivated(QSystemTrayIcon::ActivationReason r);
 
