@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITERMODEL_H
@@ -23,12 +23,23 @@ public:
     c2bCiterModel(QObject* parento = 0);
     ~c2bCiterModel();
 
-    enum Format {AJYT, JYA, T, YAJT};
+    enum Format {AJYT, IT, JYA, T, YAJT};
+
+    struct State
+    {
+        inline State() : format(AJYT) {}
+        Format format;
+        QString citation;
+    };
 
     QList<int> sizeHintForColumns() const;
     QStringList dataSelectedCiteIds() const;
     QVariant data(const QModelIndex& i, int role = Qt::DisplayRole) const;
+    State currentState(const QModelIndex& current_index) const;
     void clearSelection();
+    void loadCitations(const QString& fn);
+    void loadCitations(const QStringList& fns);
+    void reloadCitations(const QStringList& fns, const State& state, QModelIndex* current_index);
     void setFilter(const QString& pattern, QModelIndex* current_index);
     void setSelectedFilter(QModelIndex* current_index);
     void updateFormat(const Format format, QModelIndex* current_index);
@@ -77,8 +88,6 @@ public:
 
 
 public slots:
-    void loadCitations(const QString& fn);
-    void loadCitations(const QStringList& fns);
     void selectCitation(const QModelIndex& i);
 
 
@@ -91,6 +100,7 @@ private:
 
     QColor _first_column_color;
     QString _display_ajyt(const int row, const int column) const;
+    QString _display_it(const int row, const int column) const;
     QString _display_jya(const int row, const int column) const;
     QString _display_t(const int row, const int column) const;
     QString _display_yajt(const int row, const int column) const;
@@ -109,9 +119,14 @@ private:
         const int r(i.row());
         return _row_count > 0 && r >= 0 && r < _row_count;
     }
+    inline int _current_citation(const QModelIndex& current_index) const
+    {
+        return _is_index_valid(current_index) ? _offset(current_index.row()) : _previous_citation;
+    }
 
     // Model data
     Format _format;
+    QList<uint> _included_date;
     QStringList _author_string;
     QStringList _bibtex_position;
     QStringList _citeId;
@@ -127,6 +142,7 @@ private:
     QVector<int> _map_ajyt;
     QVector<int> _map_author;
     QVector<int> _map_filter;
+    QVector<int> _map_it;
     QVector<int> _map_jya;
     QVector<int> _map_t;
     QVector<int> _map_yajt;
@@ -137,6 +153,7 @@ private:
     int _citation_count;
     int _column_count;
     int _journal_max_length;
+    int _previous_citation;
     int _row_count;
 
 };
