@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterView.h"
@@ -32,15 +32,19 @@ c2bCiterView::~c2bCiterView()
 {}
 
 
-void c2bCiterView::setModel(QAbstractItemModel* citations)
+void c2bCiterView::reloadModel(QAbstractItemModel* citations, const QStringList& bibtex_files, const c2bCiterModel::State& state)
 {
+    if (!citations)
+        return;
     if (_modelP != citations)
     {
         _modelP = static_cast<c2bCiterModel*>(citations);
         QTableView::setModel(_modelP);
     }
-    setCurrentIndex(_modelP->index(0, 0));
+    QModelIndex i(currentIndex());
+    _modelP->reloadCitations(bibtex_files, state, &i);
     updateViewport();
+    updateCurrentIndex(i);
 }
 
 void c2bCiterView::resizeEvent(QResizeEvent* qevent)
@@ -96,6 +100,10 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
         updateFormat(c2bCiterModel::AJYT);
         qevent->accept();
         return;
+    case Qt::Key_I:
+        updateFormat(c2bCiterModel::IT);
+        qevent->accept();
+        return;
     case Qt::Key_J:
         updateFormat(c2bCiterModel::JYA);
         qevent->accept();
@@ -162,14 +170,12 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
 void c2bCiterView::keyboardSearch(const QString& /* search */)
 {}
 
-void c2bCiterView::updateFormat(const c2bCiterModel::Format& format)
+c2bCiterModel::State c2bCiterView::currentState() const
 {
-    if (!_modelP)
-        return;
-    QModelIndex i = currentIndex();
-    _modelP->updateFormat(format, &i);
-    updateViewport();
-    updateCurrentIndex(i);
+    if (_modelP)
+        return _modelP->currentState(currentIndex());
+    else
+        return c2bCiterModel::State();
 }
 
 void c2bCiterView::updateCurrentIndex(const QModelIndex& i)
@@ -178,6 +184,16 @@ void c2bCiterView::updateCurrentIndex(const QModelIndex& i)
     scrollTo(i, PositionAtCenter);
 }
 
+void c2bCiterView::updateFormat(const c2bCiterModel::Format& format)
+{
+    if (!_modelP)
+        return;
+    QModelIndex i(currentIndex());
+    _modelP->updateFormat(format, &i);
+    updateViewport();
+    updateCurrentIndex(i);
+}
+
 void c2bCiterView::updateViewport()
 {
     if (!_modelP)
