@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITERVIEW_H
@@ -21,7 +21,8 @@ public:
     c2bCiterView(QWidget* parentw = 0);
     ~c2bCiterView();
 
-    void setModel(QAbstractItemModel* citations);
+    c2bCiterModel::State currentState() const;
+    void reloadModel(QAbstractItemModel* citations, const QStringList& bibtex_files, const c2bCiterModel::State& state);
     void updateCurrentIndex(const QModelIndex& i);
 
 
