@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPBOARD_H
@@ -15,7 +15,7 @@
 /**
     cb2Bib Clipboard
 
-    Implements clipboard functionatility as required by cb2Bib This should fix
+    Implements clipboard functionality as required by cb2Bib This should fix
     acrobat, mozilla, qt 3.3.3 issues Using clipboardPoll
 
     @author Pere Constans
@@ -33,26 +33,23 @@ public:
     ~c2bClipboard();
 
     const QString text();
+    void setConnected(bool);
 
 
 signals:
     void cbDataChanged(const QString&);
 
 
-public slots:
-    void setConnected(bool);
-
-
 private:
-    bool isConnected;
-    bool supportsSelection;
-    QClipboard* cb;
-    QString clip;
-    QString clipS;
-    QTimer* timer;
-    uint interval;
+    QClipboard* _cb;
+    QString _cb_text;
+    QString _cbs_text;
+    QTimer* _timer;
+    bool _is_connected;
+    bool _supports_selection;
+    uint _interval;
 #ifdef CB_POLL
-    clipboardPoll* poll;
+    clipboardPoll* _poll;
 #endif
 
 
