@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -39,7 +39,7 @@
     designed are these rules, the best and most reliable will be the
     extraction. The second method, used when no regular expression matches the
     text, considers instead a set of predefined subpatterns. See \ref
-    heuristic_guess.
+    heuristicguess.
 
     At this point users can interact and supervise their references, right
     before saving them. Allowing user intervention is and has been a design
@@ -281,7 +281,7 @@ void c2bPdfImport::processOneFile()
 
 void c2bPdfImport::processNext()
 {
-    processedFile = "";
+    processedFile.clear();
     if (m_aborted)
     {
         m_aborted = false;
