@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -272,9 +272,9 @@ void c2bTests::heuristic_author()
                 QString guess_ascii(c2bUtils::toAscii(guess, c2bUtils::Cleanup));
                 passed = guess_ascii == author_ascii;
                 if (passed)
-                    cout << QString("[%1*]\t'%2'\n").arg(boolToStr(passed)).arg(author);
+                    cout << QString("[%1*] '%2'\n").arg(boolToStr(passed)).arg(author);
                 else
-                    cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed)).arg(author);
+                    cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(author);
                 if (!passed)
                 {
                     qDebug() << author;
@@ -285,10 +285,10 @@ void c2bTests::heuristic_author()
 //                        cout << '[' << doc.at(i) << ']' << " u: " << doc.at(i).unicode() << " letter: " <<
 //                             doc.at(i).isLetter() << endl;
                 }
-                cout << QString("\t'%1'\n").arg(guess);
+                cout << QString("          '%1'\n").arg(guess);
             }
             else
-                cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed)).arg(author);
+                cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(author);
             ++n_pdf;
             if (!passed) ++n_failed_pdf;
         }
@@ -592,6 +592,7 @@ void c2bTests::heuristic_pvny()
     heuristic(bp, reference, "Science 2007, 120(1): 117");
     heuristic(bp, reference, "Science 2007 120(1): 117");
     heuristic(bp, reference, "Science 2007, 120(1), 117");
+    heuristic(bp, reference, "Science, 2007, 120 (1), p 117");
     heuristic(bp, reference, "Science 2007 January 25; 120(1), 117");
     heuristic(bp, reference, "Science 2007 January 25 120(1), 117");
     heuristic(bp, reference, "Science 2007 May 25 120(1), 117");
