@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "cb2Bib.h"
@@ -47,7 +47,7 @@
     detailed list of changes and acknowledgments, and \ref relnotes for
     additional notes and information.)
 
-    See also \ref relnotes130.
+    See also \ref relnotes140
 
 <p>&nbsp;</p>
 
@@ -280,6 +280,11 @@
     correcting for author superscripts, or helps in debugging regular
     expressions.
 
+    - <b>Alt W</b> \n Writes current reference to the source document file.
+    This option is intended for writing and updating bibliographic metadata to
+    document files without needing to use BibTeX files. Only local and writable
+    files are considered.
+
     - <b>Alt X</b> \n Check Repeated looks for existing references in the
     BibTeX directory similar to the current one. The search is done for exact
     cite ID, and for title and author field values, or, if empty, for booktitle
@@ -304,12 +309,12 @@
     - \ref bibproc
     - \ref authorproc
     - \ref journalproc
-    - \ref heuristic_guess
+    - \ref heuristicguess
     - \ref regexpedit
 
     Configuration information is described in the following sections:
     - \ref c2bconf
-    - \ref id_placeholders
+    - \ref idplaceholders
 
     Utilities and modules are described in the following sections:
     - \ref c2bsearch
@@ -390,7 +395,7 @@
     The cb2Bib icons are taken from the <em>Oxygen</em>, <em>Crystal SVG</em>,
     and <em>Noia</em> icon sets, to be found at the
     \htmlonly
-    <a href="http://www.kde.org" target="_blank">KDE Desktop Environment</a>.
+    <a href="http://www.kde.org/" target="_blank">KDE Desktop Environment</a>.
     \endhtmlonly
     Several people has contributed with suggestions, bug reports or patches.
     For a detailed list of acknowledgments see the \ref changelog.
@@ -410,6 +415,46 @@
 
 /** \page relnotes Release Notes
 
+\section relnotes140 Release Note cb2Bib 1.4.0
+
+    The <tt>c2bciter</tt> module was introduced in version 1.3.0. Its name, as
+    it was described, states its purpose of being "aimed to ease inserting
+    citation IDs into documents". In fact, it does have such functionality.
+    And, it has also another, equally important one: it provides a very fast
+    way to retrieve a given work from our personal collections.
+
+    Retrieving is accomplished through pre-sorted views of the references and
+    filtering. Both, views and filtering, scale on the (tens of) thousands
+    references. Usually, we recall a work from its publication year, a few
+    words from its title, or (some of the letters of) one of its authors names.
+    Often, what we remember is when a reference was included into our
+    collection. Therefore, having such a chronological view was desirable.
+
+    The implementation of this sorted-by-inclusion-date view was not done
+    during the 1.3.x series, but postponed to version 1.4.0; somehow, to
+    indicate that some sort of 'proprietary' BibTeX tag might be required to
+    specify inclusion timestamps. I have been reluctant through the cb2Bib's
+    life span to introduce 'cb2Bib-only' tags in the BibTeX outputs. I believe
+    that there is little gain, and it costs, possibly, breaking
+    interoperability.
+
+    In the end, the choice was to not write any 'timestamp' tag in references.
+    Instead, <tt>c2bciter</tt> checks for the last modified date of the linked
+    documents to build an approximated chronological view. The advantage is
+    that all, not just 'version 1.4.0 or later', references are sorted.
+    Furthermore, if a reference is later corrected, and the document metadata
+    is updated too, the modification date is reflected in the view. The obvious
+    inconvenience is that no such sorting can be done for references without an
+    attached document.
+
+
+    See also \ref c2bciter.
+
+    <p>&nbsp;</p>
+*/
+
+/** \page relnotes Release Notes
+
 \section relnotes130 Release Note cb2Bib 1.3.0
 
     When version 0.2.7 came up, it was mentioned in \ref relnotes027, that the
@@ -1046,6 +1091,8 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
 
     QShortcut* sc = new QShortcut(QKeySequence(Qt::ALT + Qt::Key_D), this);
     connect(sc, SIGNAL(activated()), this, SLOT(deleteTmpBib()));
+    sc = new QShortcut(QKeySequence(Qt::ALT + Qt::Key_W), this);
+    connect(sc, SIGNAL(activated()), this, SLOT(addMetadata()));
     sc = new QShortcut(QKeySequence(Qt::Key_F2), this); // Made consistent with c2bCiter and c2bEditor
     connect(sc, SIGNAL(activated()), this, SLOT(hide()));
 
@@ -1064,7 +1111,7 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     BibBrowser->addActions(actions());
     ui.stackedWidget->addWidget(BibBrowser);
     connect(AboutBrowser, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(linkClicked(const QUrl&)));
-    connect(AboutBrowser, SIGNAL(highlighted(const QString&)), this, SLOT(showLink(const QString &)));
+    connect(AboutBrowser, SIGNAL(highlighted(const QString&)), this, SLOT(showLink(const QString&)));
 
     // Connect Actions
     connect(ui.checkRepeatedAction, SIGNAL(triggered()), this, SLOT(checkRepeated()));
@@ -1089,11 +1136,11 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
     // Set checkRepeated
     ui.checkRepeatedAction->setVisible(false);
     _is_check_repeated_done = false;
-    connect(ui.author, SIGNAL(textChanged(const QString &)), this, SLOT(updateCheckRepeatedAction()));
-    connect(ui.booktitle, SIGNAL(textChanged(const QString &)), this, SLOT(updateCheckRepeatedAction()));
-    connect(ui.editor, SIGNAL(textChanged(const QString &)), this, SLOT(updateCheckRepeatedAction()));
-    connect(ui.id, SIGNAL(textChanged(const QString &)), this, SLOT(updateCheckRepeatedAction()));
-    connect(ui.title, SIGNAL(textChanged(const QString &)), this, SLOT(updateCheckRepeatedAction()));
+    connect(ui.author, SIGNAL(textChanged(const QString&)), this, SLOT(updateCheckRepeatedAction()));
+    connect(ui.booktitle, SIGNAL(textChanged(const QString&)), this, SLOT(updateCheckRepeatedAction()));
+    connect(ui.editor, SIGNAL(textChanged(const QString&)), this, SLOT(updateCheckRepeatedAction()));
+    connect(ui.id, SIGNAL(textChanged(const QString&)), this, SLOT(updateCheckRepeatedAction()));
+    connect(ui.title, SIGNAL(textChanged(const QString&)), this, SLOT(updateCheckRepeatedAction()));
 
     // cb2Bib Settings
     loadSettings();
@@ -1126,12 +1173,11 @@ cb2Bib::cb2Bib(QWidget* parentw) : QMainWindow(parentw)
         _citerP = 0;
 
     // Connecting cb2Bib clipboard and start
+    c2bClipboard* cbP = c2b::clipboard();
+    connect(cbP, SIGNAL(cbDataChanged(const QString&)), this, SLOT(dataChanged(const QString&)));
     _connected = false;
-    _cbP = new c2bClipboard(this);
-    connect(_cbP, SIGNAL(cbDataChanged(const QString&)), this, SLOT(dataChanged(const QString&)));
     on_connectB_clicked(); // Set button and update _connected
-    _cbP->setConnected(_connected);
-    dataChanged(_cbP->text());
+    dataChanged(cbP->text());
     if (_settingsP->cl_bibedit)
         initAsBibTeXEditor();
 }
@@ -1185,19 +1231,20 @@ void cb2Bib::on_viewAboutB_clicked()
                 "<th>Keys</th><th>Description</th></tr>"
                 "</thead><tbody><tr>"
                 "<td>Alt A</td><td>Open cb2Bib Annote</td></tr><tr>"
-                "<td>Alt B</td><td>Edit Bookmarks</td></tr><tr>"
+                "<td>Alt B</td><td>Edit bookmarks</td></tr><tr>"
                 "<td>Alt C</td><td>Preparses cb2Bib's clipboard</td></tr><tr>"
-                "<td>Alt D</td><td>Deletes temporary BibTeX output file</td></tr><tr>"
-                "<td>Alt E</td><td>Edit Regular Expressions</td></tr><tr>"
-                "<td>Alt F</td><td>Select File source filename</td></tr><tr>"
-                "<td>Alt I</td><td>Insert Regular Expression</td></tr><tr>"
-                "<td>Alt J</td><td>Edit Journal Abbreviations</td></tr><tr>"
-                "<td>Alt O</td><td>Open File Document</td></tr><tr>"
+                "<td>Alt D</td><td>Deletes temporary BibTeX file</td></tr><tr>"
+                "<td>Alt E</td><td>Edit regular expressions</td></tr><tr>"
+                "<td>Alt F</td><td>Select source document filename</td></tr><tr>"
+                "<td>Alt I</td><td>Insert regular expression</td></tr><tr>"
+                "<td>Alt J</td><td>Edit journal abbreviations</td></tr><tr>"
+                "<td>Alt O</td><td>Open source document</td></tr><tr>"
                 "<td>Alt P</td><td>Postprocess BibTeX</td></tr><tr>"
                 "<td>Alt R</td><td>Restarts automatic recognition</td></tr><tr>"
-                "<td>Alt X</td><td>Check Repeated</td></tr><tr>"
+                "<td>Alt W</td><td>Writes metadata to source document</td></tr><tr>"
+                "<td>Alt X</td><td>Check repeated</td></tr><tr>"
                 "<td>Esc</td><td>Quits cb2Bib popup menu</td></tr><tr>"
-                "<td>Right Click</td><td>Editor popup menu"
+                "<td>Right Click</td><td>Editor's popup menu"
                 "</td></tr></tbody>"
                 "</table>"
                 "<br /> %2 <br />"
@@ -1624,7 +1671,7 @@ void cb2Bib::restartEngine()
 
 void cb2Bib::guessFields()
 {
-    QString text(ClipEdit->toPlainText());
+    const QString text(ClipEdit->toPlainText());
     if (!text.isEmpty())
     {
         const QString keep_dropped_article_file(_dropped_document_file);
@@ -1749,7 +1796,7 @@ void cb2Bib::insertRegExp()
     str.replace(QRegExp("<<author>>"), "(.+)");
     str.replace(QRegExp("<<booktitle>>"), "(.+)");
     str.replace(QRegExp("<<chapter>>"), "(\\d+)");
-    str.replace(QRegExp("<<doi>>"), "(10.[\\d\\.]+/\\S+)");
+    str.replace(QRegExp("<<doi>>"), "(10\\.[\\d\\.]+/\\S+)");
     str.replace(QRegExp("<<edition>>"), "(.+)");
     str.replace(QRegExp("<<editor>>"), "(.+)");
     str.replace(QRegExp("<<eprint>>"), "(.+)");
@@ -1776,9 +1823,8 @@ void cb2Bib::insertRegExp()
 
     // User Editting
     c2bSaveRegExp Sdiag(pattern, _raw_input_data, this);
-    connect(_cbP, SIGNAL(cbDataChanged(const QString&)), &Sdiag, SLOT(updateInput(const QString&)));
-    connect(&Sdiag, SIGNAL(savePatternInfo(const QString&, const QString&)),
-            this, SLOT(savePattern(const QString&, const QString&)));
+    connect(c2b::clipboard(), SIGNAL(cbDataChanged(const QString&)), &Sdiag, SLOT(updateInput(const QString&)));
+    connect(&Sdiag, SIGNAL(savePatternInfo(const QString&, const QString&)), this, SLOT(savePattern(const QString&, const QString&)));
     ui.connectB->setDisabled(true);
     if (Sdiag.exec() == QDialog::Rejected)
         showMessage(tr("Cancelled."));
@@ -1801,7 +1847,7 @@ void cb2Bib::savePattern(const QString& rx, const QString& rxname)
         stream.setCodec("UTF-8");
         stream.setAutoDetectUnicode(true);
         stream << ("# cb2Bib " + C2B_VERSION + "  Pattern:") << endl
-        << rxname << endl << rx << endl << endl;
+               << rxname << endl << rx << endl << endl;
         file.close();
         showMessage(tr("Pattern '%1' added to %2.").arg(rxname).arg(regular_expression_f));
     }
@@ -1861,6 +1907,18 @@ void cb2Bib::addToFile(bool ready)
                              arg(ui.bibtexfile->currentText()).arg(file.errorString()), QMessageBox::Ok);
 }
 
+void cb2Bib::addMetadata()
+{
+    if (!_dropped_document_file.isEmpty())
+    {
+        if (QFileInfo(_dropped_document_file).isWritable()
+            && c2b::metaParser()->insertMetadata(_bpP->currentReference(), _dropped_document_file))
+            c2b::showMessage(tr("Inserted metadata to file %1.").arg(_dropped_document_file));
+        else
+            c2b::showMessage(tr("Unable to insert metadata to file %1.").arg(_dropped_document_file));
+    }
+}
+
 void cb2Bib::postprocessBibTeX()
 {
     c2bPostprocess* ppBib = new c2bPostprocess(ui.bibtexfile->currentText(), this);
@@ -1962,8 +2020,8 @@ void cb2Bib::updateOpenDocuments(const QString& old_name, const QString& new_nam
     if (ed)
     {
         if (ed->objectName() == "bookmark_network_editor" ||
-                ed->objectName() == "journal_abbreviations_editor" ||
-                ed->objectName() == "regular_expression_editor")
+            ed->objectName() == "journal_abbreviations_editor" ||
+            ed->objectName() == "regular_expression_editor")
             return;
         ed->setObjectName(new_name);
         _openDocuments.insert(new_name, ed);
@@ -2049,7 +2107,7 @@ void cb2Bib::netQueryEnded(bool stat, const QString& targetPDF, const QString& t
     }
     else
     {
-        const QString previous_article_file(_dropped_document_file);   // Keep dropped file in case this is auto recognized
+        const QString previous_article_file(_dropped_document_file); // Keep dropped file in case this is auto recognized
         forceDataChange(targetBib);
         if (_bpP->isAutoRecognized() && !targetPDF.isEmpty())
             fileDropped(targetPDF);
