@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -18,7 +18,6 @@ class c2bBibMenu;
 class c2bBibParser;
 class c2bCiter;
 class c2bClipEdit;
-class c2bClipboard;
 class c2bEditor;
 class c2bNetworkQuery;
 class c2bPdfImport;
@@ -64,7 +63,6 @@ private:
     c2bCiter* _citerP;
     c2bClipEdit* BibBrowser;
     c2bClipEdit* ClipEdit;
-    c2bClipboard* _cbP;
     c2bNetworkQuery* _netQP;
     c2bSettings* _settingsP;
     c2bTextBrowser* AboutBrowser;
@@ -86,6 +84,7 @@ private slots:
     void abbreviationsEditor();
     void addAuthors();
     void addEditors();
+    void addMetadata();
     void addToFile(bool ready);
     void anyPattern();
     void bibEditor(const QString& bibtexfile, bibSearcher* searcher = 0);
