@@ -1,7 +1,7 @@
 /***************************************************************************
  *   clipboardPoll, modified by Pere Constans for the cb2Bib, 2005
  *   constans@molspaces.com
- *   cb2Bib version 1.3.6. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
  *
  *
  *   Author and Copyright (C) 2003 by Lubos Lunak <l.lunak@kde.org>
@@ -62,13 +62,14 @@ clipboardPoll::clipboardPoll(QWidget* parentw) : QWidget(parentw)
     connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
 
     const char* names[ 6 ] =
-        { "_QT_SELECTION_SENTINEL",
-          "_QT_CLIPBOARD_SENTINEL",
-          "CLIPBOARD",
-          "TIMESTAMP",
-          "KLIPPER_SELECTION_TIMESTAMP",
-          "KLIPPER_CLIPBOARD_TIMESTAMP"
-        };
+    {
+        "_QT_SELECTION_SENTINEL",
+        "_QT_CLIPBOARD_SENTINEL",
+        "CLIPBOARD",
+        "TIMESTAMP",
+        "KLIPPER_SELECTION_TIMESTAMP",
+        "KLIPPER_CLIPBOARD_TIMESTAMP"
+    };
     Atom atoms[ 6 ];
     XInternAtoms(QX11Info::display(), const_cast< char** >(names), 6, False, atoms);
     selection.sentinel_atom = atoms[ 0 ];
@@ -122,7 +123,7 @@ void clipboardPoll::updateQtOwnership(SelectionData& sData)
     unsigned char* prop = NULL;
     if (XGetWindowProperty(QX11Info::display(), QX11Info::appRootWindow(0), sData.sentinel_atom, 0, 2, False,
                            XA_WINDOW, &type, &format, &nitems, &after, &prop) != Success
-            || type != XA_WINDOW || format != 32 || nitems != 2 || prop == NULL)
+        || type != XA_WINDOW || format != 32 || nitems != 2 || prop == NULL)
     {
         sData.owner_is_qt = false;
         if (prop != NULL)
@@ -186,8 +187,8 @@ bool clipboardPoll::checkTimestamp(SelectionData& sData)
 bool clipboardPoll::changedTimestamp(SelectionData& sData, const XEvent& ev)
 {
     if (ev.xselection.requestor != winId()
-            || ev.xselection.selection != sData.atom
-            || ev.xselection.time != sData.waiting_x_time)
+        || ev.xselection.selection != sData.atom
+        || ev.xselection.time != sData.waiting_x_time)
     {
         return false;
     }
@@ -204,7 +205,7 @@ bool clipboardPoll::changedTimestamp(SelectionData& sData, const XEvent& ev)
     if (XGetWindowProperty(QX11Info::display(), winId(), ev.xselection.property, 0, 1, False,
                            AnyPropertyType, &type, &format,
                            &nitems, &after, &prop) != Success
-            || format != 32 || nitems != 1 || prop == NULL)
+        || format != 32 || nitems != 1 || prop == NULL)
     {
         if (prop != NULL)
             XFree(prop);
